#!/usr/bin/env python
#
# Copyright (c) 2016-2017, Parallels International GmbH
#
# This file is part of disp-helper. It's free software; you can redistribute
# it and/or modify it under the terms of the GNU General Public License as
# published by the Free Software Foundation; either version 2 of the License,
# or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
# 02110-1301, USA.
#
# Our contact details: Parallels International GmbH, Vordergasse 59, 8200
# Schaffhausen, Switzerland.
#

from infra_cep_helper import CEPCollecting
from lxml import etree
import os

class Storage(CEPCollecting):
    def fill_results(self):
        l = list()
        if not os.path.isdir("/etc/vstorage/clusters"):
            self.result['StorageClusters'] = l
            return

        for cluster_name in os.listdir('/etc/vstorage/clusters'):
            cluster_stats = self.execute_shell("vstorage -c " + cluster_name + " stat -X").strip()
            root = etree.fromstring(cluster_stats)
            cluster_info = {"Name": cluster_name,
                            "ID"     : root.find('./cluster_id').text,
                            "MDS"    : len(root.findall('./mds_list/mds')),
                            "CS"     : len(root.findall('./cs_list/cs')),
                            "Clients": len(root.findall('./clients_list/client')),
                            "Hosts"  : len(root.findall('./host_list/host_stat')),
                            "Repl_n" : root.find('./repl/norm').text,
                            "Repl_m" : root.find('./repl/max').text,
                            "Repl_l" : root.find('./repl/limit').text,
                            "Alloc"  : root.find('./space/allocatable').text,
                            "Eff"    : root.find('./space/effective_total').text,
                            "Alloc_r": root.find('./space/allocatable_raw').text,
                            "Total"  : root.find('./space/total').text,
                            "Total_r": root.find('./space/total_raw').text,
                            "Free"   : root.find('./space/free').text
                        }
            l.append(cluster_info)
        self.result["StorageClusters"] = l

def main():
    o = Storage()
    o.run()


if __name__ == "__main__":
    main()
